@@ -1,7 +1,6 @@
 ;;;; -*- emacs-lisp -*-
 ;;;; GNU Mailutils -- a suite of utilities for electronic mail
-;;;; Copyright (C) 2003, 2007, 2010-2012, 2014-2017 Free Software
-;;;; Foundation, Inc.
+;;;; Copyright (C) 2003-2025 Free Software Foundation, Inc.
 ;;;; 
 ;;;; GNU Mailutils is free software; you can redistribute it and/or modify
 ;;;; it under the terms of the GNU General Public License as published by
@@ -16,8 +15,8 @@
 ;;;; You should have received a copy of the GNU General Public License
 ;;;; along with GNU Mailutils.  If not, see <http://www.gnu.org/licenses/>. 
 
-(setq mh-progs "/2022Q2/bin")
-(setq mh-lib "/2022Q2/share/mailutils/mh")
+(setq mh-progs "/usr/pkg/libexec/mailutils")
+(setq mh-lib "/usr/pkg/share/mailutils/mh")
 (setq mh-lib-progs mh-progs)
 (load "mh-e")
 (setq mh-variant 'gnu-mh)
